# Amplitude changelog

## [0.1.1] - 2026-03-03
- Updated connector definition (YAML version 1.0.1)
- Source commit: 258f32e0
- SDK version: 0.1.0

## [0.1.0] - 2026-03-02
- Updated connector definition (YAML version 1.0.1)
- Source commit: 4e9e7872
- SDK version: 0.1.0
